==> lms-1.0pre1.tar.gz: lms/modules/mailingsend.php <==
<? // $Id: mailingsend.php,v 1.4 2002/11/29 19:22:36 lukasz Exp $

/*
 * LMS version 1.0
 *
 *  (C) Copyright 2002 Rulez.PL Development Team
 *  (C) Copyright 2001-2002 NetX ACN
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: mailingsend.php,v 1.4 2002/11/29 19:22:36 lukasz Exp $
 */

$layout[pagetitle]="Mailing";

$mailing = $_POST[mailing];

if($mailing[group] < 0 || $mailing[group] > 3)
	$error[group] = TRUE;

if($mailing[sender]=="")
	$error[sender] = TRUE;

if($mailing[from]=="")
	$error[from] = TRUE;

if($mailing[subject]=="")
	$error[subject] = TRUE;

if($error)
{
	$SMARTY->assign("layout",$layout);
	$SMARTY->assign("error",$error);
	$SMARTY->assign("mailing",$mailing);
	$SMARTY->display("header.html");
	$SMARTY->display("mailing.html");
	$SMARTY->display("footer.html");
}else{
	$layout[nomenu] = TRUE;
	$mailing[body] = textwrap($mailing[body]);
	$SMARTY->assign("mailing",$mailing);
	$SMARTY->assign("layout",$layout);
	$SMARTY->display("header.html");
	$SMARTY->display("mailingsend.html");
	$emails = $LMS->Mailing($mailing);
	$SMARTY->display("footer.html");
}
?>

==> lms-1.1.2b.tar.gz: lms/modules/mailingsend.php <==
<?php

/*
 * LMS version 1.1.2b
 *
 *  (C) Copyright 2001-2003 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: mailingsend.php,v 1.18 2003/08/24 13:12:54 lukasz Exp $
 */

$layout[pagetitle]="Mailing";

$mailing = $_POST[mailing];

if($mailing[group] < 0 || $mailing[group] > 3)
	$error[group] = TRUE;

if($mailing[sender]=="")
	$error[sender] = TRUE;

if($mailing[from]=="")
	$error[from] = TRUE;

if($mailing[subject]=="")
	$error[subject] = TRUE;

if($error)
{
	$SMARTY->assign("layout",$layout);
	$SMARTY->assign("error",$error);
	$SMARTY->assign("mailing",$mailing);
	$SMARTY->display("header.html");
	$SMARTY->display("mailing.html");
	$SMARTY->display("footer.html");
}else{
	$layout[nomenu] = TRUE;
	$mailing[body] = textwrap($mailing[body]);
	$SMARTY->assign("mailing",$mailing);
	$SMARTY->assign("layout",$layout);
	$SMARTY->display("header.html");
	$SMARTY->display("mailingsend.html");
	$emails = $LMS->Mailing($mailing);
	$SMARTY->display("mailingsend-footer.html");
	$SMARTY->display("footer.html");
}
/*
 * $Log: mailingsend.php,v $
 * Revision 1.18  2003/08/24 13:12:54  lukasz
 * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
 *   redhat's :>
 *
 * Revision 1.17  2003/08/18 16:52:19  lukasz
 * - added CVS Log tags
 *
 */
?>
